Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProcessDeletedMessage ¶
func ProcessDeletedMessage(m *models.DigestMessageDeleted)
ProcessDeletedMessage is responsible for dealing with deletion events sent from the remote RTM server
func ProcessIncomingMessage ¶
func ProcessIncomingMessage(m *models.DigestMessage)
ProcessIncomingMessage deals with incoming messages from the remote RTM server. It is also called by ProcessUpdatedMessage when an updated message is not on our records.
func ProcessReaction ¶
func ProcessReaction(m *models.DigestMessageReaction)
ProcessReaction deals with incoming reaction events from the RTM server updating the current document. It also performs cleanup operations when a given reaction is no longer present.
func ProcessUpdatedMessage ¶
func ProcessUpdatedMessage(m *models.DigestMessageChanged)
ProcessUpdatedMessage checks an updated message consistency and updates the detected URL, before enqueuing the model for a Prefetch operation. If the updated text did not had an URL, it won't be found on the collection, which will cause this method to handle the incoming data to ProcessIncomingMessage.
Types ¶
This section is empty.